//  mpl_clp.cpp
//  
//  Copyright 2003  Brady Hunsaker
//  Created:  2003 May 17
//
//  License:  You may use this file under the terms of your choice of 
//    the GNU General Public License (GPL) version 2, or the 
//    Common Public License (CPL), used by the COIN-OR project.
//
//  This is an example program showing how the function readGNUMathProg 
//  can be used in conjunction with COIN-OR/OSI.
//
//  Note that the functionality of this program is very weak.  It's just
//  an example!  
//

#include "OsiClpSolverInterface.hpp"
#include "ReadGNUMathProg.hpp"

int main ( int argc, char* argv[])
{
  if (argc < 2 || argc > 3)
    {
      cout << "Usage: mpl_cpl <filename> [<datafilename>]" << endl;
      exit(1);
    }

  char *filename = argv[1];
  char *dataname = NULL;
  if (argc == 3)
    dataname = argv[2];

  OsiSolverInterface * si = new OsiClpSolverInterface;

  int ret_code = readGNUMathProg( si, filename, dataname );

  if (ret_code == -1)
    {
      cout << "Errors interpreting model" << endl;
      exit(1);
    }
  else if (ret_code == 2)  // MIP problem
    {
      cout << "CPL can not solve MIPs (other open-source software in " 
	   << "COIN-OR can do this, though)" << endl;
      exit(1);
    }

  // otherwise ret_code should be 1 for an LP

  si->initialSolve();
  
  // Check the solution
  if ( si->isProvenOptimal() )
    { 
      cout << "Found optimal solution!" << endl; 
      cout << "Objective value is " << si->getObjValue() << endl;

      int n = si->getNumCols();
      const double *solution;
      solution = si->getColSolution();
      // We could then print the solution or examine it.
    }
  else
    {
      cout << "Didn't find optimal solution." << endl;
      // Could then check other status functions.
    }

  return 0;
}
